@@ -121,8 +121,7 @@ namespace libtorrent { namespace aux {
 		friend void* asio_handler_allocate(
 			std::size_t size, allocating_handler<Handler, Size>* ctx)
 		{
-			TORRENT_UNUSED(size);
-			TORRENT_ASSERT_VAL(size <= Size, size);
+			if (size > Size) return std::malloc(size);
 #if TORRENT_USE_ASSERTS
 			TORRENT_ASSERT(!ctx->storage.used);
 			ctx->storage.used = true;
@@ -133,11 +132,9 @@ namespace libtorrent { namespace aux {
 		friend void asio_handler_deallocate(
 			void* ptr, std::size_t size, allocating_handler<Handler, Size>* ctx)
 		{
-			TORRENT_UNUSED(ptr);
-			TORRENT_UNUSED(size);
 			TORRENT_UNUSED(ctx);
 
-			TORRENT_ASSERT_VAL(size <= Size, size);
+			if (size > Size) return std::free(ptr);
 			TORRENT_ASSERT(ptr == &ctx->storage.bytes);
 #if TORRENT_USE_ASSERTS
 			ctx->storage.used = false;
