@@ -337,7 +337,7 @@ namespace aux {
 			using connection_map = std::set<std::shared_ptr<peer_connection>>;
 			using torrent_map = std::unordered_map<sha1_hash, std::shared_ptr<torrent>>;
 
-			session_impl(io_service& ios, settings_pack const& pack);
+			session_impl(io_service& ios, settings_pack const& pack, session_flags_t);
 			~session_impl() override;
 
 			void start_session();
@@ -1261,9 +1261,9 @@ namespace aux {
 
 			// abort may not fail and cannot allocate memory
 #if defined BOOST_ASIO_ENABLE_HANDLER_TRACKING
-			aux::handler_storage<100> m_abort_handler_storage;
+			aux::handler_storage<104> m_abort_handler_storage;
 #else
-			aux::handler_storage<88> m_abort_handler_storage;
+			aux::handler_storage<96> m_abort_handler_storage;
 #endif
 
 			// torrents are announced on the local network in a
@@ -1354,7 +1354,7 @@ namespace aux {
 			// message in-flight at any given time.
 			bool m_pending_auto_manage = false;
 
-			// this is also set to true when triggering an auto-manage
+			// this is set to true when triggering an auto-manage
 			// of the torrents. However, if the normal auto-manage
 			// timer comes along and executes the auto-management,
 			// this is set to false, which means the triggered event
