@@ -36,13 +36,14 @@ POSSIBILITY OF SUCH DAMAGE.
 #include "libtorrent/config.hpp"
 
 #include "libtorrent/aux_/throw.hpp"
-#include "libtorrent/aux_/vector.hpp"
 #include "libtorrent/aux_/numeric_cast.hpp"
 #include "libtorrent/time.hpp"
 #include "libtorrent/assert.hpp"
 #include "libtorrent/debug.hpp" // for single_threaded
 
 #include <cstdlib>
+#include <memory> // for unique_ptr
+#include <vector>
 
 namespace libtorrent {
 
